@@ -724,7 +724,7 @@ sunone_invitation_list_model_set_value (SunOneInvitationListModel *model, int co
 		wcap = sunone_connection_get_wcap (cnc, key);
 		g_free (key);
 		if (wcap) {
-			char *string = icalcomponent_as_ical_string (clonecomp);
+			char *string = icalcomponent_as_ical_string_r (clonecomp);
 
 			cal_backend_wcap_events_update_objects (E_CAL_BACKEND_SYNC (wcap),
 					NULL, string, CALOBJ_MOD_ALL, NULL, NULL);
